ApiClient class

Implemented types

Constructors

ApiClient({required BaseOptions options, List<Interceptor> interceptors = const []})

Properties

cacheOptions → CacheOptions?
no setter
client ↔ Dio
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attachCacheInterceptor(CacheInterceptor cacheInterceptor) → void
override
attachCharlesProxy(String? charlesIp, String? port) → void
attachInterceptors() → void
override
attachLoggerInterceptor() → void
override
clearCache() Future<void>
customCacheKeyBuilder(RequestOptions request) String
deAttachInterceptors() → void
override
getCachePolicy({required bool forceRefresh}) → CachePolicy
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateClientBaseUrl(String baseUrl) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited