BaseApiClient<T> class abstract

Implementers

Constructors

BaseApiClient()

Properties

client ↔ T
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attachCacheInterceptor(CacheInterceptor cacheInterceptor) → void
attachInterceptors() → void
attachLoggerInterceptor() → void
deAttachInterceptors() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

kAcceptHeader → const String
kAuthHeader → const String
kAuthPrefix → const String
kContentTypeHeader → const String
kJsonPrefix → const String
kMediaJPEG → const String
kMediaPNG → const String
kMultipartPrefix → const String