CacheInterceptor class abstract interface

Properties

cacheOptions ↔ CacheOptions?
getter/setter pair
client → Dio
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attachCacheInterceptor() Future<void>
clearCache() Future<void>
createOptions() Future<CacheOptions>
customCacheKeyBuilder(RequestOptions request) String
deAttachInterceptor() → void
getCachePolicy({required bool forceRefresh}) → CachePolicy
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited