DioClientModule class abstract

Constructors

DioClientModule()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createInternalDioRequestProcessor({RetryPolicy? retryPolicy, ConnectionChecker? connectionChecker, ErrorProcessor? errorProcessor, OnCustomError? customErrorParser}) RequestProcessor
makeApiClient(ApiClientParams params) ApiClient
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultMaxAttemptsCount → const int
Number of attempts to re-execute the request
defaultRetryStatusCodes → const List<int>
Error codes that require re-execution of the request (without bad request) Basic list of error codes that require re-execution of the request