HttpStatus class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- badGateway → const int
- badRequest → const int
- forbidden → const int
- internalServerError → const int
- kCodeSuccess200 → const int
- kCodeSuccess201 → const int
- networkConnectTimeoutError → const int
- notFound → const int
- notImplemented → const int
- tooManyRequests → const int
- unprocessedEntity → const int
- unsupportedMediaType → const int