KeyValueReloadableStorage<T> class abstract

Inheritance
Implementers

Constructors

KeyValueReloadableStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
inherited
contains(String key) Future<bool>
inherited
create() Future<T>
inherited
get<K>(String key, K defaultValue) Future<K>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put<K>(String key, K value) Future<void>
inherited
reload() Future<void>
remove(String key) Future<bool>
inherited
storage() Future<T>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited