KeyValueStorage<T> class abstract

Implementers

Constructors

KeyValueStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
contains(String key) Future<bool>
create() Future<T>
get<K>(String key, K defaultValue) Future<K>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put<K>(String key, K value) Future<void>
remove(String key) Future<bool>
storage() Future<T>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited