SharedPreferencesStorage class

Inheritance

Constructors

SharedPreferencesStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
override
contains(String key) Future<bool>
override
create() Future<SharedPreferences>
override
get<K>(String key, K defaultValue) Future<K>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put<K>(String key, K value) Future<void>
override
reload() Future<void>
override
remove(String key) Future<bool>
override
storage() Future<SharedPreferences>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited