UndefinedError<T> class final

Inheritance

Constructors

UndefinedError(Object? errorObject, [int? statusCode, StackTrace? trace])

Properties

data → T
no setterinherited
errorObject Object?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
no setter
trace StackTrace?
no setter

Methods

isError() bool
inherited
isSuccess() bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited