DataResponse<T> class
abstract
Constructors
- DataResponse()
-
const
- DataResponse.apiError(Object error, [int? statusCode])
-
factory
- DataResponse.canceledRequest()
-
factory
- DataResponse.notConnected()
-
factory
- DataResponse.success(T data)
-
factory
- DataResponse.tooManyRequests()
-
factory
-
factory
- DataResponse.undefinedError(Object? errorObject, [int? statusCode, StackTrace? trace])
-
factory
Properties
- data → T
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isError(
) → bool -
isSuccess(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited