InternalDioRequestProcessor class
- Inheritance
-
- Object
- RequestProcessor
- InternalDioRequestProcessor
Constructors
- InternalDioRequestProcessor({RetryPolicy? retryPolicy, ErrorProcessor? errorProcessor, ConnectionChecker? connectionChecker, OnCustomError? onCustomError})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
hasInternetConnection(
ConnectionChecker connectionChecker) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processRequest<
T, R> ({required OnRequest< T> onRequest, required OnParse<R> onParse, OnCustomError? onCustomRequestError, bool checkNetworkConnection = true}) → Future<DataResponse< R> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited