RetryPolicy class abstract
Constructors
-
RetryPolicy({required int maxAttemptsCount, required List<
int> retryStatusCodes})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAttemptsCount → int
-
final
-
retryStatusCodes
→ List<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onRetry(
{required Exception exception}) → FutureOr< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited